package utils

import (
	"fmt"
	beeLogger "github.com/beego/bee/v2/logger"
	"github.com/beego/beego/v2/server/web"
	"go.mongodb.org/mongo-driver/mongo"
	"strconv"
)

var (
	RunMode                string //运行模式
	APP_NAME_CN            string
	MYSQL_URL              string        //数据库连接
	MYSQL_URL_WEEKLY_TRIAL string        //eta试用数据库
	Re                     error         //redis错误
	Rc                     RedisClient   //redis缓存
	MgoUrlData             string        // mongodb数据库连接配置
	MgoDataCli             *mongo.Client // mongodb客户端连接
	MgoDataDbName          string        // mongodb指标数据的库名
)

// ES配置
var (
	ES_URL      string // ES服务器地址
	ES_USERNAME string // ES账号
	ES_PASSWORD string // ES密码
)

// ES索引配置
var (
	DATA_INDEX_NAME  string //数据指标库索引
	CHART_INDEX_NAME string //研究图库索引
)

// 弘则
const (
	APPID  = "SJCrpOPvagscPxEv"
	SECRET = "gLLjT72uFHQZEFtaFCuoZegD1z2ezfyX"
)

// 日志配置
var (
	LogPath     string //调用过程中的日志存放地址
	LogFile     string
	LogDataPath string //调用过程中图表相关的日志存放地址
	LogDataFile string
	BinLogPath  string //数据库相关的日志存放地址
	BinLogFile  string
	ApiLogPath  string //接口请求地址和接口返回值日志存放地址
	ApiLogFile  string
	LogMaxDays  int //日志最大保留天数
)

// 基础配置
var (
	DesKey string // 接口返回加密KEY
)

// AlarmMsgUrl 报警服务地址
var AlarmMsgUrl string

// CrmEtaServerUrl CRM-ETA服务地址
var CrmEtaServerUrl string
var CrmEtaAuthorization string

func init() {
	tmpRunMode, err := web.AppConfig.String("run_mode")
	if err != nil {
		panic("配置文件读取run_mode错误 " + err.Error())
	}
	RunMode = tmpRunMode
	fmt.Println("RunMode:", RunMode)
	if RunMode == "" {
		localIp, err := GetLocalIP()
		fmt.Println("localIp:", localIp)
		if localIp == "10.0.0.123" {
			RunMode = "debug"
		} else {
			RunMode = "release"
		}
		fmt.Println("RunMode:", RunMode)
		configPath := `/home/code/config/eta_forum_admin/conf/app.conf`
		fmt.Println("configPath:", configPath)
		err = web.LoadAppConfig("ini", configPath)
		if err != nil {
			fmt.Println("web.LoadAppConfig Err:" + err.Error())
		}
	}
	config, err := web.AppConfig.GetSection(RunMode)
	if err != nil {
		panic("配置文件读取错误 " + err.Error())
	}
	beeLogger.Log.Info(RunMode + " 模式")
	// 项目中文名称
	appNameCn, err := web.AppConfig.String("app_name_cn")
	if err != nil {
		panic(any("配置文件读取app_name_cn错误 " + err.Error()))
	}
	APP_NAME_CN = appNameCn
	MYSQL_URL = config["mysql_url"]
	MYSQL_URL_WEEKLY_TRIAL = config["mysql_url_weekly_trial"]
	// mongodb数据库连接配置
	MgoUrlData = config["mgo_url_data"]
	//日志配置
	{
		LogPath = config["log_path"]
		LogFile = config["log_file"]
		LogDataPath = config["log_data_path"]
		LogDataFile = config["log_data_file"]
		BinLogPath = config["binlog_path"]
		BinLogFile = config["binlog_file"]
		ApiLogPath = config["apilog_path"]
		ApiLogFile = config["apilog_file"]
		logMaxDaysStr := config["log_max_day"]
		LogMaxDays, _ = strconv.Atoi(logMaxDaysStr)
	}
	// 接口返回加密KEY
	DesKey = config["des_key"]
	{
		// 报警服务地址
		AlarmMsgUrl = config["alarm_msg_url"]

	}

	// 初始化缓存
	redisClient, err := initRedis(config["redis_type"], config["beego_cache"])
	if err != nil {
		fmt.Println("redis链接异常：", err)
		panic(any(Re))
	}

	Rc = redisClient

	// ES配置
	{
		ES_URL = config["es_url"]
		ES_USERNAME = config["es_username"]
		ES_PASSWORD = config["es_password"]
	}

	// 初始化ES
	initEs()

	// ES 索引
	{
		DATA_INDEX_NAME = config["data_index_name"]
		CHART_INDEX_NAME = config["chart_index_name"]
	}

	// CRM-ETA服务地址
	CrmEtaServerUrl = "http://127.0.0.1:8708"
	if config["crm_eta_server_url"] != "" {
		CrmEtaServerUrl = config["crm_eta_server_url"]
	}
	CrmEtaAuthorization = "NIi1RbEmH0C2rksXtPGDPBBgRgTZY87Q"
	if config["crm_eta_authorization"] != "" {
		CrmEtaAuthorization = config["crm_eta_authorization"]
	}

}

//修改接口文档
//http://8.136.199.33:8300/swagger/
